Server & Tools
==============

MCP server entry point and tool implementations.

.. automodule:: curate_ipsum.server
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.tools
   :members:
   :show-inheritance:
